# in-container

> Allows you to check if you program is running inside a Docker container

## Install

```
$ pip install in-container
```

## Usage

```python
from in_container import in_container
print(in_container()) # True or False
```

## License

[MIT](https://github.com/ZiggerZZ/in_container/blob/master/LICENSE)
